const char stress_config[] = 
"#define HAVE_ACCEPT4\n"
"#define HAVE_ACL_LIBACL_H\n"
"#define HAVE_ADJTIME\n"
"#define HAVE_ADJTIMEX\n"
"#define HAVE_AIO_CANCEL\n"
"#define HAVE_AIO_FSYNC\n"
"#define HAVE_AIO_H\n"
"#define HAVE_AIO_READ\n"
"#define HAVE_AIO_WRITE\n"
"#define HAVE_ALIGNED_128\n"
"#define HAVE_ALIGNED_64\n"
"#define HAVE_ALIGNED_64K\n"
"#define HAVE_ALIGNED_ALLOC\n"
"#define HAVE_APPARMOR\n"
"#define HAVE_ARC4RANDOM\n"
"#define HAVE_ARCH_PRCTL\n"
"#define HAVE_ASM_LDT_H\n"
"#define HAVE_ASM_MB\n"
"#define HAVE_ASM_MTRR_H\n"
"#define HAVE_ASM_NOP\n"
"#define HAVE_ASM_NOTHING\n"
"#define HAVE_ASM_PRCTL_H\n"
"#define HAVE_ASM_X86_CLDEMOTE\n"
"#define HAVE_ASM_X86_CLFLUSH\n"
"#define HAVE_ASM_X86_CLFLUSHOPT\n"
"#define HAVE_ASM_X86_CLTS\n"
"#define HAVE_ASM_X86_CLWB\n"
"#define HAVE_ASM_X86_HLT\n"
"#define HAVE_ASM_X86_INVD\n"
"#define HAVE_ASM_X86_INVLPG\n"
"#define HAVE_ASM_X86_LAHF\n"
"#define HAVE_ASM_X86_LFENCE\n"
"#define HAVE_ASM_X86_LGDT\n"
"#define HAVE_ASM_X86_LLDT\n"
"#define HAVE_ASM_X86_LMSW\n"
"#define HAVE_ASM_X86_MFENCE\n"
"#define HAVE_ASM_X86_MOVDIRI\n"
"#define HAVE_ASM_X86_MOV_CR0\n"
"#define HAVE_ASM_X86_MOV_DR0\n"
"#define HAVE_ASM_X86_PAUSE\n"
"#define HAVE_ASM_X86_PREFETCHNTA\n"
"#define HAVE_ASM_X86_PREFETCHT0\n"
"#define HAVE_ASM_X86_PREFETCHT1\n"
"#define HAVE_ASM_X86_PREFETCHT2\n"
"#define HAVE_ASM_X86_PREFETCHW\n"
"#define HAVE_ASM_X86_PREFETCHWT1\n"
"#define HAVE_ASM_X86_RDMSR\n"
"#define HAVE_ASM_X86_RDPMC\n"
"#define HAVE_ASM_X86_RDRAND\n"
"#define HAVE_ASM_X86_RDSEED\n"
"#define HAVE_ASM_X86_RDTSC\n"
"#define HAVE_ASM_X86_RDTSCP\n"
"#define HAVE_ASM_X86_REP_STOSB\n"
"#define HAVE_ASM_X86_REP_STOSD\n"
"#define HAVE_ASM_X86_REP_STOSQ\n"
"#define HAVE_ASM_X86_REP_STOSW\n"
"#define HAVE_ASM_X86_SERIALIZE\n"
"#define HAVE_ASM_X86_SFENCE\n"
"#define HAVE_ASM_X86_TPAUSE\n"
"#define HAVE_ASM_X86_WRINVD\n"
"#define HAVE_ASM_X86_WRMSR\n"
"#define HAVE_ATOMIC\n"
"#define HAVE_ATOMIC_ADD_FETCH\n"
"#define HAVE_ATOMIC_AND_FETCH\n"
"#define HAVE_ATOMIC_CLEAR\n"
"#define HAVE_ATOMIC_COMPARE_EXCHANGE\n"
"#define HAVE_ATOMIC_FETCH_ADD\n"
"#define HAVE_ATOMIC_FETCH_ADD_2\n"
"#define HAVE_ATOMIC_FETCH_ADD_4\n"
"#define HAVE_ATOMIC_FETCH_ADD_8\n"
"#define HAVE_ATOMIC_FETCH_AND\n"
"#define HAVE_ATOMIC_FETCH_NAND\n"
"#define HAVE_ATOMIC_FETCH_OR\n"
"#define HAVE_ATOMIC_FETCH_SUB\n"
"#define HAVE_ATOMIC_FETCH_XOR\n"
"#define HAVE_ATOMIC_LOAD\n"
"#define HAVE_ATOMIC_LOAD_DOUBLE\n"
"#define HAVE_ATOMIC_NAND_FETCH\n"
"#define HAVE_ATOMIC_OR_FETCH\n"
"#define HAVE_ATOMIC_STORE\n"
"#define HAVE_ATOMIC_STORE_DOUBLE\n"
"#define HAVE_ATOMIC_SUB_FETCH\n"
"#define HAVE_ATOMIC_TEST_AND_SET\n"
"#define HAVE_ATOMIC_XOR_FETCH\n"
"#define HAVE_ATTRIBUTE_ALWAYS_INLINE\n"
"#define HAVE_ATTRIBUTE_CONST\n"
"#define HAVE_ATTRIBUTE_FAST_MATH\n"
"#define HAVE_ATTRIBUTE_NOINLINE\n"
"#define HAVE_ATTRIBUTE_NORETURN\n"
"#define HAVE_ATTRIBUTE_PACKED\n"
"#define HAVE_ATTRIBUTE_PURE\n"
"#define HAVE_ATTRIBUTE_RETURNS_NONNULL\n"
"#define HAVE_ATTRIBUTE_WARN_UNUSED_RESULT\n"
"#define HAVE_ATTRIBUTE_WEAK\n"
"#define HAVE_BACKTRACE\n"
"#define HAVE_BRK\n"
"#define HAVE_BSD_STDLIB_H\n"
"#define HAVE_BSD_STRING_H\n"
"#define HAVE_BSD_STRLCAT\n"
"#define HAVE_BSD_STRLCPY\n"
"#define HAVE_BSD_SYS_TREE_H\n"
"#define HAVE_BSD_UNISTD_H\n"
"#define HAVE_BSD_WCHAR_H\n"
"#define HAVE_BSEARCH\n"
"#define HAVE_BUILTIN_ASSUME_ALIGNED\n"
"#define HAVE_BUILTIN_BSWAP32\n"
"#define HAVE_BUILTIN_CABS\n"
"#define HAVE_BUILTIN_CABSF\n"
"#define HAVE_BUILTIN_CABSL\n"
"#define HAVE_BUILTIN_CBRT\n"
"#define HAVE_BUILTIN_CBRTF\n"
"#define HAVE_BUILTIN_CBRTL\n"
"#define HAVE_BUILTIN_CCOS\n"
"#define HAVE_BUILTIN_CCOSF\n"
"#define HAVE_BUILTIN_CCOSH\n"
"#define HAVE_BUILTIN_CCOSHF\n"
"#define HAVE_BUILTIN_CCOSHL\n"
"#define HAVE_BUILTIN_CCOSL\n"
"#define HAVE_BUILTIN_CEXP\n"
"#define HAVE_BUILTIN_CEXPF\n"
"#define HAVE_BUILTIN_CEXPL\n"
"#define HAVE_BUILTIN_CLOG\n"
"#define HAVE_BUILTIN_CLOGF\n"
"#define HAVE_BUILTIN_CLOGL\n"
"#define HAVE_BUILTIN_CLZ\n"
"#define HAVE_BUILTIN_CLZL\n"
"#define HAVE_BUILTIN_CLZLL\n"
"#define HAVE_BUILTIN_COMPLEX\n"
"#define HAVE_BUILTIN_CONSTANT_P\n"
"#define HAVE_BUILTIN_COS\n"
"#define HAVE_BUILTIN_COSF\n"
"#define HAVE_BUILTIN_COSHF\n"
"#define HAVE_BUILTIN_COSHL\n"
"#define HAVE_BUILTIN_COSL\n"
"#define HAVE_BUILTIN_CPOW\n"
"#define HAVE_BUILTIN_CPOWF\n"
"#define HAVE_BUILTIN_CPOWL\n"
"#define HAVE_BUILTIN_CSIN\n"
"#define HAVE_BUILTIN_CSINF\n"
"#define HAVE_BUILTIN_CSINH\n"
"#define HAVE_BUILTIN_CSINHF\n"
"#define HAVE_BUILTIN_CSINHL\n"
"#define HAVE_BUILTIN_CSINL\n"
"#define HAVE_BUILTIN_CSQRT\n"
"#define HAVE_BUILTIN_CSQRTF\n"
"#define HAVE_BUILTIN_CSQRTL\n"
"#define HAVE_BUILTIN_CTAN\n"
"#define HAVE_BUILTIN_CTANF\n"
"#define HAVE_BUILTIN_CTANH\n"
"#define HAVE_BUILTIN_CTANHF\n"
"#define HAVE_BUILTIN_CTANHL\n"
"#define HAVE_BUILTIN_CTANL\n"
"#define HAVE_BUILTIN_CTZ\n"
"#define HAVE_BUILTIN_EXP\n"
"#define HAVE_BUILTIN_EXP10\n"
"#define HAVE_BUILTIN_EXP10F\n"
"#define HAVE_BUILTIN_EXP10L\n"
"#define HAVE_BUILTIN_EXP2\n"
"#define HAVE_BUILTIN_EXP2F\n"
"#define HAVE_BUILTIN_EXP2L\n"
"#define HAVE_BUILTIN_EXPECT\n"
"#define HAVE_BUILTIN_EXPF\n"
"#define HAVE_BUILTIN_EXPL\n"
"#define HAVE_BUILTIN_FABS\n"
"#define HAVE_BUILTIN_FABSF\n"
"#define HAVE_BUILTIN_FABSL\n"
"#define HAVE_BUILTIN_FMA\n"
"#define HAVE_BUILTIN_FMAF\n"
"#define HAVE_BUILTIN_HYPOT\n"
"#define HAVE_BUILTIN_HYPOTF\n"
"#define HAVE_BUILTIN_HYPOTL\n"
"#define HAVE_BUILTIN_IA32_MOVNTDQ\n"
"#define HAVE_BUILTIN_IA32_MOVNTI\n"
"#define HAVE_BUILTIN_IA32_MOVNTI64\n"
"#define HAVE_BUILTIN_J0\n"
"#define HAVE_BUILTIN_J0F\n"
"#define HAVE_BUILTIN_J0L\n"
"#define HAVE_BUILTIN_J1\n"
"#define HAVE_BUILTIN_J1F\n"
"#define HAVE_BUILTIN_J1L\n"
"#define HAVE_BUILTIN_JN\n"
"#define HAVE_BUILTIN_JNF\n"
"#define HAVE_BUILTIN_JNL\n"
"#define HAVE_BUILTIN_LGAMMAL\n"
"#define HAVE_BUILTIN_LLABS\n"
"#define HAVE_BUILTIN_LOG\n"
"#define HAVE_BUILTIN_LOG10\n"
"#define HAVE_BUILTIN_LOG10F\n"
"#define HAVE_BUILTIN_LOG10L\n"
"#define HAVE_BUILTIN_LOG2\n"
"#define HAVE_BUILTIN_LOG2F\n"
"#define HAVE_BUILTIN_LOG2L\n"
"#define HAVE_BUILTIN_LOGB\n"
"#define HAVE_BUILTIN_LOGBF\n"
"#define HAVE_BUILTIN_LOGBL\n"
"#define HAVE_BUILTIN_LOGF\n"
"#define HAVE_BUILTIN_LOGL\n"
"#define HAVE_BUILTIN_MEMCMP\n"
"#define HAVE_BUILTIN_MEMCPY\n"
"#define HAVE_BUILTIN_MEMMOVE\n"
"#define HAVE_BUILTIN_MEMSET\n"
"#define HAVE_BUILTIN_PARITY\n"
"#define HAVE_BUILTIN_POPCOUNT\n"
"#define HAVE_BUILTIN_POPCOUNTL\n"
"#define HAVE_BUILTIN_POPCOUNTLL\n"
"#define HAVE_BUILTIN_POW\n"
"#define HAVE_BUILTIN_POWF\n"
"#define HAVE_BUILTIN_POWL\n"
"#define HAVE_BUILTIN_PREFETCH\n"
"#define HAVE_BUILTIN_RINT\n"
"#define HAVE_BUILTIN_RINTL\n"
"#define HAVE_BUILTIN_ROUNDL\n"
"#define HAVE_BUILTIN_SFENCE\n"
"#define HAVE_BUILTIN_SHUFFLE\n"
"#define HAVE_BUILTIN_SIN\n"
"#define HAVE_BUILTIN_SINCOS\n"
"#define HAVE_BUILTIN_SINCOSF\n"
"#define HAVE_BUILTIN_SINCOSL\n"
"#define HAVE_BUILTIN_SINF\n"
"#define HAVE_BUILTIN_SINH\n"
"#define HAVE_BUILTIN_SINHF\n"
"#define HAVE_BUILTIN_SINHL\n"
"#define HAVE_BUILTIN_SINL\n"
"#define HAVE_BUILTIN_SQRT\n"
"#define HAVE_BUILTIN_SQRTF\n"
"#define HAVE_BUILTIN_SQRTL\n"
"#define HAVE_BUILTIN_STDC_ROTATE_LEFT\n"
"#define HAVE_BUILTIN_STDC_ROTATE_RIGHT\n"
"#define HAVE_BUILTIN_STRDUP\n"
"#define HAVE_BUILTIN_SUPPORTS\n"
"#define HAVE_BUILTIN_TAN\n"
"#define HAVE_BUILTIN_TANF\n"
"#define HAVE_BUILTIN_TANH\n"
"#define HAVE_BUILTIN_TANHF\n"
"#define HAVE_BUILTIN_TANHL\n"
"#define HAVE_BUILTIN_TANL\n"
"#define HAVE_BUILTIN_THREAD_POINTER\n"
"#define HAVE_BUILTIN_Y0\n"
"#define HAVE_BUILTIN_Y0F\n"
"#define HAVE_BUILTIN_Y0L\n"
"#define HAVE_BUILTIN_Y1\n"
"#define HAVE_BUILTIN_Y1F\n"
"#define HAVE_BUILTIN_Y1L\n"
"#define HAVE_BUILTIN_YN\n"
"#define HAVE_BUILTIN_YNF\n"
"#define HAVE_BUILTIN_YNL\n"
"#define HAVE_BUILTIN___CLEAR_CACHE\n"
"#define HAVE_CABSL\n"
"#define HAVE_CBRT\n"
"#define HAVE_CBRTF\n"
"#define HAVE_CBRTL\n"
"#define HAVE_CCOS\n"
"#define HAVE_CCOSF\n"
"#define HAVE_CCOSH\n"
"#define HAVE_CCOSHF\n"
"#define HAVE_CCOSHL\n"
"#define HAVE_CCOSL\n"
"#define HAVE_CDROM_BLK\n"
"#define HAVE_CDROM_MCN\n"
"#define HAVE_CDROM_MSF\n"
"#define HAVE_CDROM_READ_AUDIO\n"
"#define HAVE_CDROM_SUBCHNL\n"
"#define HAVE_CDROM_TI\n"
"#define HAVE_CDROM_TOCENTRY\n"
"#define HAVE_CDROM_TOCHDR\n"
"#define HAVE_CDROM_VOLCTRL\n"
"#define HAVE_CEXP\n"
"#define HAVE_CEXPF\n"
"#define HAVE_CEXPL\n"
"#define HAVE_CFGETISPEED\n"
"#define HAVE_CFGETOSPEED\n"
"#define HAVE_CHROOT\n"
"#define HAVE_CIMAG\n"
"#define HAVE_CIMAGF\n"
"#define HAVE_CIMAGL\n"
"#define HAVE_CLEARENV\n"
"#define HAVE_CLOCK_ADJTIME\n"
"#define HAVE_CLOCK_GETRES\n"
"#define HAVE_CLOCK_GETTIME\n"
"#define HAVE_CLOCK_NANOSLEEP\n"
"#define HAVE_CLOCK_SETTIME\n"
"#define HAVE_CLOG\n"
"#define HAVE_CLOGF\n"
"#define HAVE_CLOGL\n"
"#define HAVE_CLONE\n"
"#define HAVE_CLOSE_RANGE\n"
"#define HAVE_COMPLEX\n"
"#define HAVE_COMPLEX_H\n"
"#define HAVE_CONSOLEFONTDESC\n"
"#define HAVE_COPY_FILE_RANGE\n"
"#define HAVE_COSH\n"
"#define HAVE_COSHF\n"
"#define HAVE_COSHL\n"
"#define HAVE_COSL\n"
"#define HAVE_CPOW\n"
"#define HAVE_CPOWF\n"
"#define HAVE_CPOWL\n"
"#define HAVE_CPU_SET_T\n"
"#define HAVE_CREAL\n"
"#define HAVE_CREALF\n"
"#define HAVE_CREALL\n"
"#define HAVE_CRYPT_H\n"
"#define HAVE_CRYPT_R\n"
"#define HAVE_CSIN\n"
"#define HAVE_CSINF\n"
"#define HAVE_CSINH\n"
"#define HAVE_CSINHF\n"
"#define HAVE_CSINHL\n"
"#define HAVE_CSINL\n"
"#define HAVE_CSQRT\n"
"#define HAVE_CSQRTF\n"
"#define HAVE_CSQRTL\n"
"#define HAVE_CTAN\n"
"#define HAVE_CTANF\n"
"#define HAVE_CTANH\n"
"#define HAVE_CTANHF\n"
"#define HAVE_CTANHL\n"
"#define HAVE_CTANL\n"
"#define HAVE_DADDR_T\n"
"#define HAVE_DIRENT_D_TYPE\n"
"#define HAVE_DM_IOCTL\n"
"#define HAVE_DRAND48\n"
"#define HAVE_DUP3\n"
"#define HAVE_DVD_AUTHINFO\n"
"#define HAVE_DVD_STRUCT\n"
"#define HAVE_Decimal128\n"
"#define HAVE_Decimal32\n"
"#define HAVE_Decimal64\n"
"#define HAVE_EIGEN\n"
"#define HAVE_ENDMNTENT\n"
"#define HAVE_ENDPWENT\n"
"#define HAVE_EPOLL_CREATE\n"
"#define HAVE_EPOLL_CREATE1\n"
"#define HAVE_EVENTFD\n"
"#define HAVE_EXECINFO_H\n"
"#define HAVE_EXECUTABLE_START\n"
"#define HAVE_EXECVEAT\n"
"#define HAVE_EXP\n"
"#define HAVE_EXP10\n"
"#define HAVE_EXP10F\n"
"#define HAVE_EXP10L\n"
"#define HAVE_EXP2\n"
"#define HAVE_EXP2F\n"
"#define HAVE_EXP2L\n"
"#define HAVE_EXPF\n"
"#define HAVE_EXPL\n"
"#define HAVE_FACCESSAT\n"
"#define HAVE_FALLOCATE\n"
"#define HAVE_FANOTIFY\n"
"#define HAVE_FCHMODAT\n"
"#define HAVE_FCHOWNAT\n"
"#define HAVE_FDATASYNC\n"
"#define HAVE_FEATURES_H\n"
"#define HAVE_FENV_H\n"
"#define HAVE_FEXECVE\n"
"#define HAVE_FGETXATTR\n"
"#define HAVE_FLISTXATTR\n"
"#define HAVE_FLOAT_H\n"
"#define HAVE_FLOCK\n"
"#define HAVE_FLOPPY_DRIVE_STRUCT\n"
"#define HAVE_FLOPPY_FDC_STATE\n"
"#define HAVE_FLOPPY_STRUCT\n"
"#define HAVE_FLOPPY_WRITE_ERRORS\n"
"#define HAVE_FMA\n"
"#define HAVE_FMAF\n"
"#define HAVE_FREMOVEXATTR\n"
"#define HAVE_FSETXATTR\n"
"#define HAVE_FSTAT\n"
"#define HAVE_FSTATAT\n"
"#define HAVE_FSUUID2\n"
"#define HAVE_FSVERITY_DIGEST\n"
"#define HAVE_FSVERITY_ENABLE_ARG\n"
"#define HAVE_FSXATTR_STRUCT\n"
"#define HAVE_FSYNC\n"
"#define HAVE_FS_SYSFS_PATH\n"
"#define HAVE_FUTIMENS\n"
"#define HAVE_FUTIMES\n"
"#define HAVE_FUTIMESAT_DEPRECATED\n"
"#define HAVE_Float128\n"
"#define HAVE_Float16\n"
"#define HAVE_Float32\n"
"#define HAVE_Float32x\n"
"#define HAVE_Float64\n"
"#define HAVE_Float64x\n"
"#define HAVE_GETAUXVAL\n"
"#define HAVE_GETCPU\n"
"#define HAVE_GETDOMAINNAME\n"
"#define HAVE_GETDTABLESIZE\n"
"#define HAVE_GETENTROPY\n"
"#define HAVE_GETGROUPS\n"
"#define HAVE_GETHOSTID\n"
"#define HAVE_GETHOSTNAME\n"
"#define HAVE_GETITIMER\n"
"#define HAVE_GETLOADAVG\n"
"#define HAVE_GETLOGIN\n"
"#define HAVE_GETMNTENT\n"
"#define HAVE_GETPAGESIZE\n"
"#define HAVE_GETPGID\n"
"#define HAVE_GETPGRP\n"
"#define HAVE_GETPRIORITY\n"
"#define HAVE_GETPWENT\n"
"#define HAVE_GETRANDOM\n"
"#define HAVE_GETRESGID\n"
"#define HAVE_GETRESUID\n"
"#define HAVE_GETRUSAGE\n"
"#define HAVE_GETSID\n"
"#define HAVE_GETTID\n"
"#define HAVE_GETTIMEOFDAY\n"
"#define HAVE_GETXATTR\n"
"#define HAVE_GMP_H\n"
"#define HAVE_GRP_H\n"
"#define HAVE_HSEARCH\n"
"#define HAVE_HYPOT\n"
"#define HAVE_HYPOTF\n"
"#define HAVE_HYPOTL\n"
"#define HAVE_ICMPHDR\n"
"#define HAVE_IFADDRS_H\n"
"#define HAVE_IFCONF\n"
"#define HAVE_IFREQ\n"
"#define HAVE_IMMINTRIN_H\n"
"#define HAVE_INDEX\n"
"#define HAVE_INO64_T\n"
"#define HAVE_INOTIFY\n"
"#define HAVE_INOTIFY1\n"
"#define HAVE_INT128_T\n"
"#define HAVE_INTRINSIC_ROLB\n"
"#define HAVE_INTRINSIC_ROLD\n"
"#define HAVE_INTRINSIC_ROLQ\n"
"#define HAVE_INTRINSIC_ROLW\n"
"#define HAVE_INTRINSIC_RORB\n"
"#define HAVE_INTRINSIC_RORD\n"
"#define HAVE_INTRINSIC_RORQ\n"
"#define HAVE_INTRINSIC_RORW\n"
"#define HAVE_INT_FAST16_T\n"
"#define HAVE_INT_FAST32_T\n"
"#define HAVE_INT_FAST64_T\n"
"#define HAVE_INT_FAST8_T\n"
"#define HAVE_IOPL\n"
"#define HAVE_IOPORT\n"
"#define HAVE_IO_URING_SQE_ADDR3\n"
"#define HAVE_IPHDR\n"
"#define HAVE_ITIMER_WHICH_T\n"
"#define HAVE_J0\n"
"#define HAVE_J0F\n"
"#define HAVE_J0L\n"
"#define HAVE_J1\n"
"#define HAVE_J1F\n"
"#define HAVE_J1L\n"
"#define HAVE_JN\n"
"#define HAVE_JNF\n"
"#define HAVE_JNL\n"
"#define HAVE_JUDY_H\n"
"#define HAVE_KBDIACRS\n"
"#define HAVE_KBENTRY\n"
"#define HAVE_KBKEYCODE\n"
"#define HAVE_KBSENTRY\n"
"#define HAVE_KERNEL_LONG_T\n"
"#define HAVE_KERNEL_ULONG_T\n"
"#define HAVE_KEYUTILS_H\n"
"#define HAVE_KEY_T\n"
"#define HAVE_LABEL_AS_VALUE\n"
"#define HAVE_LANDLOCK_RULESET_ATTR\n"
"#define HAVE_LANDLOCK_RULE_TYPE\n"
"#define HAVE_LGAMMAL\n"
"#define HAVE_LGETXATTR\n"
"#define HAVE_LIBAIO_H\n"
"#define HAVE_LIBGEN_H\n"
"#define HAVE_LIBJPEG_H\n"
"#define HAVE_LIBKMOD_H\n"
"#define HAVE_LIB_ACL\n"
"#define HAVE_LIB_AIO\n"
"#define HAVE_LIB_BSD\n"
"#define HAVE_LIB_CRYPT\n"
"#define HAVE_LIB_DL\n"
"#define HAVE_LIB_GMP\n"
"#define HAVE_LIB_JPEG\n"
"#define HAVE_LIB_JUDY\n"
"#define HAVE_LIB_KMOD\n"
"#define HAVE_LIB_LZMA\n"
"#define HAVE_LIB_MD\n"
"#define HAVE_LIB_MPFR\n"
"#define HAVE_LIB_PTHREAD\n"
"#define HAVE_LIB_PTHREAD_SPINLOCK\n"
"#define HAVE_LIB_RT\n"
"#define HAVE_LIB_SCTP\n"
"#define HAVE_LIB_XXHASH\n"
"#define HAVE_LIB_Z\n"
"#define HAVE_LINKAT\n"
"#define HAVE_LINK_H\n"
"#define HAVE_LINUX_ANDROID_BINDERFS_H\n"
"#define HAVE_LINUX_ANDROID_BINDER_H\n"
"#define HAVE_LINUX_AUDIT_H\n"
"#define HAVE_LINUX_AUTO_DEV_IOCTL_H\n"
"#define HAVE_LINUX_BLKZONED_H\n"
"#define HAVE_LINUX_BTRFS_H\n"
"#define HAVE_LINUX_CDROM_H\n"
"#define HAVE_LINUX_CN_PROC_H\n"
"#define HAVE_LINUX_CONNECTOR_H\n"
"#define HAVE_LINUX_DM_IOCTL_H\n"
"#define HAVE_LINUX_FB_H\n"
"#define HAVE_LINUX_FD_H\n"
"#define HAVE_LINUX_FIEMAP_H\n"
"#define HAVE_LINUX_FILTER_H\n"
"#define HAVE_LINUX_FSVERITY_H\n"
"#define HAVE_LINUX_FS_H\n"
"#define HAVE_LINUX_FUTEX_H\n"
"#define HAVE_LINUX_GENETLINK_H\n"
"#define HAVE_LINUX_HDREG_H\n"
"#define HAVE_LINUX_HIDDEV\n"
"#define HAVE_LINUX_HIDRAW_H\n"
"#define HAVE_LINUX_HPET_H\n"
"#define HAVE_LINUX_IF_ALG_H\n"
"#define HAVE_LINUX_IF_PACKET_H\n"
"#define HAVE_LINUX_IF_TUN_H\n"
"#define HAVE_LINUX_INPUT_H\n"
"#define HAVE_LINUX_IO_URING_H\n"
"#define HAVE_LINUX_KD_H\n"
"#define HAVE_LINUX_KVM_H\n"
"#define HAVE_LINUX_LANDLOCK_H\n"
"#define HAVE_LINUX_LIRC_H\n"
"#define HAVE_LINUX_LOOP_H\n"
"#define HAVE_LINUX_LSM_H\n"
"#define HAVE_LINUX_MAGIC_H\n"
"#define HAVE_LINUX_MEDIA_H\n"
"#define HAVE_LINUX_MEMBARRIER_H\n"
"#define HAVE_LINUX_MEMFD_H\n"
"#define HAVE_LINUX_MEMPOLICY_H\n"
"#define HAVE_LINUX_MODULE_H\n"
"#define HAVE_LINUX_NETLINK_H\n"
"#define HAVE_LINUX_OPENAT2_H\n"
"#define HAVE_LINUX_PCI_H\n"
"#define HAVE_LINUX_PERF_EVENT_H\n"
"#define HAVE_LINUX_POSIX_TYPES_H\n"
"#define HAVE_LINUX_PPDEV_H\n"
"#define HAVE_LINUX_PTP_CLOCK_H\n"
"#define HAVE_LINUX_RANDOM_H\n"
"#define HAVE_LINUX_RSEQ_H\n"
"#define HAVE_LINUX_RTC_H\n"
"#define HAVE_LINUX_RTNETLINK_H\n"
"#define HAVE_LINUX_SCHED_H\n"
"#define HAVE_LINUX_SECCOMP_H\n"
"#define HAVE_LINUX_SERIAL_H\n"
"#define HAVE_LINUX_SOCKET_H\n"
"#define HAVE_LINUX_SOCKIOS_H\n"
"#define HAVE_LINUX_SOCK_DIAG_H\n"
"#define HAVE_LINUX_SYSCTL_H\n"
"#define HAVE_LINUX_TASKSTATS_H\n"
"#define HAVE_LINUX_UDP_H\n"
"#define HAVE_LINUX_UINPUT_H\n"
"#define HAVE_LINUX_UNIX_DIAG_H\n"
"#define HAVE_LINUX_USBDEVICE_FS_H\n"
"#define HAVE_LINUX_USB_CDC_WDM_H\n"
"#define HAVE_LINUX_USERFAULTFD_H\n"
"#define HAVE_LINUX_VERSION_H\n"
"#define HAVE_LINUX_VIDEODEV2_H\n"
"#define HAVE_LINUX_VT_H\n"
"#define HAVE_LINUX_WATCHDOG_H\n"
"#define HAVE_LISTXATTR\n"
"#define HAVE_LLISTXATTR\n"
"#define HAVE_LOCALE_H\n"
"#define HAVE_LOCALTIME_R\n"
"#define HAVE_LOCKF\n"
"#define HAVE_LOFF_T\n"
"#define HAVE_LOG\n"
"#define HAVE_LOG10\n"
"#define HAVE_LOG10F\n"
"#define HAVE_LOG10L\n"
"#define HAVE_LOG2\n"
"#define HAVE_LOG2F\n"
"#define HAVE_LOG2L\n"
"#define HAVE_LOGB\n"
"#define HAVE_LOGBF\n"
"#define HAVE_LOGBL\n"
"#define HAVE_LOGF\n"
"#define HAVE_LOGL\n"
"#define HAVE_LOOKUP_DCOOKIE\n"
"#define HAVE_LRAND48\n"
"#define HAVE_LREMOVEXATTR\n"
"#define HAVE_LSEARCH\n"
"#define HAVE_LSEEK64\n"
"#define HAVE_LSETXATTR\n"
"#define HAVE_LSTAT\n"
"#define HAVE_LZMA_H\n"
"#define HAVE_M128I_U\n"
"#define HAVE_M256I_U\n"
"#define HAVE_MADVISE\n"
"#define HAVE_MALLOC_H\n"
"#define HAVE_MALLOC_TRIM\n"
"#define HAVE_MALLOC_USABLE_SIZE\n"
"#define HAVE_MALLOPT\n"
"#define HAVE_MEDIA_DEVICE_INFO\n"
"#define HAVE_MEMALIGN\n"
"#define HAVE_MEMFD_CREATE\n"
"#define HAVE_MINCORE\n"
"#define HAVE_MKDIRAT\n"
"#define HAVE_MKFIFO\n"
"#define HAVE_MKNOD\n"
"#define HAVE_MKNODAT\n"
"#define HAVE_MLOCK\n"
"#define HAVE_MLOCK2\n"
"#define HAVE_MLOCKALL\n"
"#define HAVE_MM256_ADD_EPI8\n"
"#define HAVE_MM256_DPBUSD_EPI32\n"
"#define HAVE_MM256_DPWSSD_EPI32\n"
"#define HAVE_MM256_LOADU_SI256\n"
"#define HAVE_MM256_STOREU_SI256\n"
"#define HAVE_MM512_ADD_EPI8\n"
"#define HAVE_MM512_DPBUSD_EPI32\n"
"#define HAVE_MM512_DPWSSD_EPI32\n"
"#define HAVE_MM512_LOADU_SI512\n"
"#define HAVE_MM512_STOREU_SI512\n"
"#define HAVE_MM_ADD_EPI8\n"
"#define HAVE_MM_DPBUSD_EPI32\n"
"#define HAVE_MM_DPWSSD_EPI32\n"
"#define HAVE_MM_GETCSR\n"
"#define HAVE_MM_LOADU_SI128\n"
"#define HAVE_MM_SETCSR\n"
"#define HAVE_MM_STOREU_SI128\n"
"#define HAVE_MNTENT_H\n"
"#define HAVE_MNT_ID_REQ\n"
"#define HAVE_MODE_T\n"
"#define HAVE_MODIFY_LDT\n"
"#define HAVE_MPFR_H\n"
"#define HAVE_MPROTECT\n"
"#define HAVE_MQUEUE_H\n"
"#define HAVE_MQ_POSIX\n"
"#define HAVE_MQ_SYSV\n"
"#define HAVE_MREMAP\n"
"#define HAVE_MSGINFO\n"
"#define HAVE_MSYNC\n"
"#define HAVE_MTRR_GENTRY\n"
"#define HAVE_MTRR_SENTRY\n"
"#define HAVE_MTX_DESTROY\n"
"#define HAVE_MTX_INIT\n"
"#define HAVE_MTX_T\n"
"#define HAVE_MUNLOCK\n"
"#define HAVE_MUNLOCKALL\n"
"#define HAVE_NAME_TO_HANDLE_AT\n"
"#define HAVE_NANOSLEEP\n"
"#define HAVE_NETINET_IP_H\n"
"#define HAVE_NETINET_IP_ICMP_H\n"
"#define HAVE_NETINET_SCTP_H\n"
"#define HAVE_NETINET_TCP_H\n"
"#define HAVE_NETINET_UDP_H\n"
"#define HAVE_NET_IF_H\n"
"#define HAVE_NICE\n"
"#define HAVE_OFF64_T\n"
"#define HAVE_OFF_T\n"
"#define HAVE_OPENAT\n"
"#define HAVE_OPENAT2\n"
"#define HAVE_OPEN_BY_HANDLE_AT\n"
"#define HAVE_OPEN_MEMSTREAM\n"
"#define HAVE_PAGE_REGION\n"
"#define HAVE_PATHCONF\n"
"#define HAVE_PAUSE\n"
"#define HAVE_PERSONALITY\n"
"#define HAVE_PIDFD_GETFD\n"
"#define HAVE_PIDFD_OPEN\n"
"#define HAVE_PIDFD_SEND_SIGNAL\n"
"#define HAVE_PID_TYPE\n"
"#define HAVE_PIPE2\n"
"#define HAVE_PKEY_ALLOC\n"
"#define HAVE_PKEY_FREE\n"
"#define HAVE_PKEY_GET\n"
"#define HAVE_PKEY_MPROTECT\n"
"#define HAVE_PKEY_SET\n"
"#define HAVE_PM_SCAN_ARG\n"
"#define HAVE_POLL\n"
"#define HAVE_POLL_H\n"
"#define HAVE_POSIX_FADVISE\n"
"#define HAVE_POSIX_FALLOCATE\n"
"#define HAVE_POSIX_MADVISE\n"
"#define HAVE_POSIX_MEMALIGN\n"
"#define HAVE_POSIX_OPENPT\n"
"#define HAVE_POSIX_SPAWN\n"
"#define HAVE_POW\n"
"#define HAVE_POWF\n"
"#define HAVE_POWL\n"
"#define HAVE_PPOLL\n"
"#define HAVE_PRAGMA\n"
"#define HAVE_PRAGMA_INSIDE\n"
"#define HAVE_PRAGMA_PREFETCH\n"
"#define HAVE_PRCTL\n"
"#define HAVE_PREAD\n"
"#define HAVE_PREADV\n"
"#define HAVE_PREADV2\n"
"#define HAVE_PRIORITY_WHICH_T\n"
"#define HAVE_PRLIMIT\n"
"#define HAVE_PROCESS_VM_READV\n"
"#define HAVE_PROCESS_VM_WRITEV\n"
"#define HAVE_PROCMAP_QUERY\n"
"#define HAVE_PROGRAM_INVOCATION_NAME\n"
"#define HAVE_PSELECT\n"
"#define HAVE_PTHREAD_ATTR_SETSTACK\n"
"#define HAVE_PTHREAD_BARRIER\n"
"#define HAVE_PTHREAD_H\n"
"#define HAVE_PTHREAD_MUTEXATTR_DESTROY\n"
"#define HAVE_PTHREAD_MUTEXATTR_INIT\n"
"#define HAVE_PTHREAD_MUTEXATTR_SETPRIOCEILING\n"
"#define HAVE_PTHREAD_MUTEXATTR_SETPROTOCOL\n"
"#define HAVE_PTHREAD_MUTEXATTR_SETROBUST\n"
"#define HAVE_PTHREAD_MUTEXATTR_T\n"
"#define HAVE_PTHREAD_MUTEX_DESTROY\n"
"#define HAVE_PTHREAD_MUTEX_INIT\n"
"#define HAVE_PTHREAD_MUTEX_T\n"
"#define HAVE_PTHREAD_PRIO_INHERIT\n"
"#define HAVE_PTHREAD_PRIO_NONE\n"
"#define HAVE_PTHREAD_PRIO_PROTECT\n"
"#define HAVE_PTHREAD_SETAFFINITY_NP\n"
"#define HAVE_PTHREAD_SETSCHEDPARAM\n"
"#define HAVE_PTHREAD_SIGQUEUE\n"
"#define HAVE_PTRACE\n"
"#define HAVE_PTRACE_REQUEST\n"
"#define HAVE_PTSNAME\n"
"#define HAVE_PWRITE\n"
"#define HAVE_PWRITEV\n"
"#define HAVE_PWRITEV2\n"
"#define HAVE_RANDOM\n"
"#define HAVE_READAHEAD\n"
"#define HAVE_READLINKAT\n"
"#define HAVE_READV\n"
"#define HAVE_RECVMMSG\n"
"#define HAVE_RECVMSG\n"
"#define HAVE_REGCOMP\n"
"#define HAVE_REGERROR\n"
"#define HAVE_REGEXEC\n"
"#define HAVE_REGEX_H\n"
"#define HAVE_REGFREE\n"
"#define HAVE_REMAP_FILE_PAGES\n"
"#define HAVE_REMOVEXATTR\n"
"#define HAVE_RENAMEAT\n"
"#define HAVE_RENAMEAT2\n"
"#define HAVE_RINDEX\n"
"#define HAVE_RINTL\n"
"#define HAVE_RLIMIT_RESOURCE_T\n"
"#define HAVE_ROUNDL\n"
"#define HAVE_RTC_PARAM\n"
"#define HAVE_RUSAGE_RU_MAXRSS\n"
"#define HAVE_RUSAGE_RU_MINFLT\n"
"#define HAVE_RUSAGE_RU_NVCSW\n"
"#define HAVE_RUSAGE_WHO_T\n"
"#define HAVE_SBRK\n"
"#define HAVE_SCHED_GETAFFINITY\n"
"#define HAVE_SCHED_GETCPU\n"
"#define HAVE_SCHED_GET_PRIORITY_MAX\n"
"#define HAVE_SCHED_GET_PRIORITY_MIN\n"
"#define HAVE_SCHED_RR_GET_INTERVAL\n"
"#define HAVE_SCHED_SETAFFINITY\n"
"#define HAVE_SCHED_SETSCHEDULER\n"
"#define HAVE_SCHED_YIELD\n"
"#define HAVE_SCSI_SCSI_H\n"
"#define HAVE_SCSI_SCSI_IOCTL_H\n"
"#define HAVE_SCSI_SG_H\n"
"#define HAVE_SCTP_ASSOCPARAMS\n"
"#define HAVE_SCTP_ASSOC_STATS\n"
"#define HAVE_SCTP_ASSOC_VALUE\n"
"#define HAVE_SCTP_DEFAULT_PRINFO\n"
"#define HAVE_SCTP_EVENT_SUBSCRIBE\n"
"#define HAVE_SCTP_GETADDRS\n"
"#define HAVE_SCTP_INITMSG\n"
"#define HAVE_SCTP_PADDRINFO\n"
"#define HAVE_SCTP_PADDRPARAMS\n"
"#define HAVE_SCTP_PRIM\n"
"#define HAVE_SCTP_PROBEINTERVAL\n"
"#define HAVE_SCTP_RTOINFO\n"
"#define HAVE_SCTP_SCHED_TYPE\n"
"#define HAVE_SCTP_SETADAPTION\n"
"#define HAVE_SCTP_STATUS\n"
"#define HAVE_SCTP_STREAM_VALUE\n"
"#define HAVE_SCTP_UDPENCAPS\n"
"#define HAVE_SEARCH_H\n"
"#define HAVE_SECCOMP_NOTIF_SIZES\n"
"#define HAVE_SEED48\n"
"#define HAVE_SELECT\n"
"#define HAVE_SEMAPHORE_H\n"
"#define HAVE_SEMTIMEDOP\n"
"#define HAVE_SEM_POSIX\n"
"#define HAVE_SEM_SYSV\n"
"#define HAVE_SENDFILE\n"
"#define HAVE_SENDMMSG\n"
"#define HAVE_SENDMSG\n"
"#define HAVE_SERIAL_ICOUNTER\n"
"#define HAVE_SERIAL_STRUCT\n"
"#define HAVE_SETDOMAINNAME\n"
"#define HAVE_SETFSGID\n"
"#define HAVE_SETFSUID\n"
"#define HAVE_SETGROUPS\n"
"#define HAVE_SETITIMER\n"
"#define HAVE_SETMNTENT\n"
"#define HAVE_SETNS\n"
"#define HAVE_SETPGID\n"
"#define HAVE_SETPGRP\n"
"#define HAVE_SETPRIORITY\n"
"#define HAVE_SETPROCTITLE\n"
"#define HAVE_SETPROCTITLE_INIT\n"
"#define HAVE_SETPWENT\n"
"#define HAVE_SETREGID\n"
"#define HAVE_SETRESGID\n"
"#define HAVE_SETRESUID\n"
"#define HAVE_SETREUID\n"
"#define HAVE_SETTIMEOFDAY\n"
"#define HAVE_SETXATTR\n"
"#define HAVE_SHMID_DS\n"
"#define HAVE_SHMINFO\n"
"#define HAVE_SHM_OPEN\n"
"#define HAVE_SHM_SYSV\n"
"#define HAVE_SHM_UNLINK\n"
"#define HAVE_SIGALTSTACK\n"
"#define HAVE_SIGLONGJMP\n"
"#define HAVE_SIGNALFD\n"
"#define HAVE_SIGQUEUE\n"
"#define HAVE_SIGWAITINFO\n"
"#define HAVE_SINCOS\n"
"#define HAVE_SINCOSF\n"
"#define HAVE_SINCOSL\n"
"#define HAVE_SINH\n"
"#define HAVE_SINHF\n"
"#define HAVE_SINHL\n"
"#define HAVE_SINL\n"
"#define HAVE_SND_CTL_CARD_INFO\n"
"#define HAVE_SND_CTL_TLV\n"
"#define HAVE_SOCKADDR_UN\n"
"#define HAVE_SOUND_ASOUND_H\n"
"#define HAVE_SPAWN_H\n"
"#define HAVE_SPLICE\n"
"#define HAVE_SQRT\n"
"#define HAVE_SQRTF\n"
"#define HAVE_SQRTL\n"
"#define HAVE_SRAND48\n"
"#define HAVE_SRANDOM\n"
"#define HAVE_STAT\n"
"#define HAVE_STATFS\n"
"#define HAVE_STATX\n"
"#define HAVE_STRINGS_H\n"
"#define HAVE_SWAP\n"
"#define HAVE_SWAPCONTEXT\n"
"#define HAVE_SYMLINKAT\n"
"#define HAVE_SYNC\n"
"#define HAVE_SYNCFS\n"
"#define HAVE_SYNC_BOOL_COMPARE_AND_SWAP\n"
"#define HAVE_SYNC_FILE_RANGE\n"
"#define HAVE_SYNC_SYNCHRONIZE\n"
"#define HAVE_SYNC_VAL_COMPARE_AND_SWAP\n"
"#define HAVE_SYSCALL\n"
"#define HAVE_SYSCALL_H\n"
"#define HAVE_SYSINFO\n"
"#define HAVE_SYSLOG_H\n"
"#define HAVE_SYS_ACL_H\n"
"#define HAVE_SYS_APPARMOR_H\n"
"#define HAVE_SYS_AUXV_H\n"
"#define HAVE_SYS_CAPABILITY_H\n"
"#define HAVE_SYS_EPOLL_H\n"
"#define HAVE_SYS_EVENTFD_H\n"
"#define HAVE_SYS_FANOTIFY_H\n"
"#define HAVE_SYS_FILE_H\n"
"#define HAVE_SYS_FSUID_H\n"
"#define HAVE_SYS_INOTIFY_H\n"
"#define HAVE_SYS_IO_H\n"
"#define HAVE_SYS_IPC_H\n"
"#define HAVE_SYS_MOUNT_H\n"
"#define HAVE_SYS_MSG_H\n"
"#define HAVE_SYS_PARAM_H\n"
"#define HAVE_SYS_PERSONALITY_H\n"
"#define HAVE_SYS_PIDFD_H\n"
"#define HAVE_SYS_PRCTL_H\n"
"#define HAVE_SYS_QUEUE_H\n"
"#define HAVE_SYS_QUOTA_H\n"
"#define HAVE_SYS_RANDOM_H\n"
"#define HAVE_SYS_RSEQ_H\n"
"#define HAVE_SYS_SELECT_H\n"
"#define HAVE_SYS_SENDFILE_H\n"
"#define HAVE_SYS_SHM_H\n"
"#define HAVE_SYS_SIGNALFD_H\n"
"#define HAVE_SYS_STATFS_H\n"
"#define HAVE_SYS_STATVFS_H\n"
"#define HAVE_SYS_SWAP_H\n"
"#define HAVE_SYS_SYSINFO_H\n"
"#define HAVE_SYS_SYSMACROS_H\n"
"#define HAVE_SYS_TIMERFD_H\n"
"#define HAVE_SYS_TIMEX_H\n"
"#define HAVE_SYS_UIO_H\n"
"#define HAVE_SYS_UN_H\n"
"#define HAVE_SYS_UTSNAME_H\n"
"#define HAVE_SYS_VFS_H\n"
"#define HAVE_SYS_XATTR_H\n"
"#define HAVE_TANHL\n"
"#define HAVE_TANL\n"
"#define HAVE_TARGET_CLONES\n"
"#define HAVE_TARGET_CLONES_ALDERLAKE\n"
"#define HAVE_TARGET_CLONES_ARROWLAKE\n"
"#define HAVE_TARGET_CLONES_AVX\n"
"#define HAVE_TARGET_CLONES_AVX2\n"
"#define HAVE_TARGET_CLONES_COOPERLAKE\n"
"#define HAVE_TARGET_CLONES_DIAMONDRAPIDS\n"
"#define HAVE_TARGET_CLONES_GRANITERAPIDS\n"
"#define HAVE_TARGET_CLONES_LUNARLAKE\n"
"#define HAVE_TARGET_CLONES_MMX\n"
"#define HAVE_TARGET_CLONES_PANTHERLAKE\n"
"#define HAVE_TARGET_CLONES_ROCKETLAKE\n"
"#define HAVE_TARGET_CLONES_SAPPHIRERAPIDS\n"
"#define HAVE_TARGET_CLONES_SKYLAKE_AVX512\n"
"#define HAVE_TARGET_CLONES_SSE\n"
"#define HAVE_TARGET_CLONES_SSE2\n"
"#define HAVE_TARGET_CLONES_SSE3\n"
"#define HAVE_TARGET_CLONES_SSE4_1\n"
"#define HAVE_TARGET_CLONES_SSE4_2\n"
"#define HAVE_TARGET_CLONES_SSSE3\n"
"#define HAVE_TARGET_CLONES_TIGERLAKE\n"
"#define HAVE_TARGET_CLONES_ZNVER1\n"
"#define HAVE_TARGET_CLONES_ZNVER2\n"
"#define HAVE_TARGET_CLONES_ZNVER3\n"
"#define HAVE_TARGET_CLONES_ZNVER4\n"
"#define HAVE_TARGET_CLONES_ZNVER5\n"
"#define HAVE_TCDRAIN\n"
"#define HAVE_TCFLOW\n"
"#define HAVE_TCFLUSH\n"
"#define HAVE_TCGETATTR\n"
"#define HAVE_TEE\n"
"#define HAVE_TERMIOS\n"
"#define HAVE_TERMIOS_H\n"
"#define HAVE_TGKILL_LIBC\n"
"#define HAVE_THREADS_H\n"
"#define HAVE_TIME\n"
"#define HAVE_TIMERFD_CREATE\n"
"#define HAVE_TIMERFD_GETTIME\n"
"#define HAVE_TIMERFD_SETTIME\n"
"#define HAVE_TIMER_CREATE\n"
"#define HAVE_TIMER_DELETE\n"
"#define HAVE_TIMER_GETOVERRUN\n"
"#define HAVE_TIMER_GETTIME\n"
"#define HAVE_TIMER_SETTIME\n"
"#define HAVE_TIMEX\n"
"#define HAVE_TIMEZONE\n"
"#define HAVE_TPACKET_REQ3\n"
"#define HAVE_TSEARCH\n"
"#define HAVE_TTYNAME\n"
"#define HAVE_UCONTEXT_H\n"
"#define HAVE_UMOUNT2\n"
"#define HAVE_UNAME\n"
"#define HAVE_UNIMAPDESC\n"
"#define HAVE_UNLINKAT\n"
"#define HAVE_UNSHARE\n"
"#define HAVE_USBDEVFS_GETDRIVER\n"
"#define HAVE_USER_DESC\n"
"#define HAVE_UTIMBUF\n"
"#define HAVE_UTIME\n"
"#define HAVE_UTIMENSAT\n"
"#define HAVE_UTIMES\n"
"#define HAVE_UTIME_H\n"
"#define HAVE_V2DI\n"
"#define HAVE_V4L2_AUDIO\n"
"#define HAVE_V4L2_AUDIOOUT\n"
"#define HAVE_V4L2_CAPABILITY\n"
"#define HAVE_V4L2_DV_TIMINGS\n"
"#define HAVE_V4L2_ENC_IDX\n"
"#define HAVE_V4L2_FRAMEBUFFER\n"
"#define HAVE_V4L2_JPEGCOMPRESSION\n"
"#define HAVE_V4L2_STD_ID\n"
"#define HAVE_VALLOC\n"
"#define HAVE_VECMATH\n"
"#define HAVE_VFORK\n"
"#define HAVE_VHANGUP\n"
"#define HAVE_VLA_ARG\n"
"#define HAVE_VMSPLICE\n"
"#define HAVE_VT_CONSIZE\n"
"#define HAVE_VT_MODE\n"
"#define HAVE_VT_SIZES\n"
"#define HAVE_VT_STAT\n"
"#define HAVE_WAIT3\n"
"#define HAVE_WAIT4\n"
"#define HAVE_WAITID\n"
"#define HAVE_WAITPID\n"
"#define HAVE_WCHAR_H\n"
"#define HAVE_WCSCASECMP\n"
"#define HAVE_WCSCAT\n"
"#define HAVE_WCSCHR\n"
"#define HAVE_WCSCMP\n"
"#define HAVE_WCSCOLL\n"
"#define HAVE_WCSCPY\n"
"#define HAVE_WCSLCAT\n"
"#define HAVE_WCSLCPY\n"
"#define HAVE_WCSLEN\n"
"#define HAVE_WCSNCASECMP\n"
"#define HAVE_WCSNCAT\n"
"#define HAVE_WCSNCMP\n"
"#define HAVE_WCSRCHR\n"
"#define HAVE_WCSXFRM\n"
"#define HAVE_WINSIZE\n"
"#define HAVE_WRITEV\n"
"#define HAVE_X86INTRIN_H\n"
"#define HAVE_XMMINTRIN_H\n"
"#define HAVE_XXHASH_H\n"
"#define HAVE_Y0\n"
"#define HAVE_Y0F\n"
"#define HAVE_Y0L\n"
"#define HAVE_Y1\n"
"#define HAVE_Y1F\n"
"#define HAVE_Y1L\n"
"#define HAVE_YN\n"
"#define HAVE_YNF\n"
"#define HAVE_YNL\n"
"#define HAVE___RESTRICT\n"
"#define HAVE___RSEQ_OFFSET\n"
"#define HAVE__bf16\n"
"#define HAVE__float128\n"
"#define HAVE__float80\n"
"/* #define HAVE_ASM_ALPHA_DRAINA */\n"
"/* #define HAVE_ASM_ALPHA_HALT */\n"
"/* #define HAVE_ASM_ARM_DMB_SY */\n"
"/* #define HAVE_ASM_ARM_PRFM */\n"
"/* #define HAVE_ASM_ARM_TLBI */\n"
"/* #define HAVE_ASM_ARM_YIELD */\n"
"/* #define HAVE_ASM_CACHECTL_H */\n"
"/* #define HAVE_ASM_HPPA_DIAG */\n"
"/* #define HAVE_ASM_HPPA_RFI */\n"
"/* #define HAVE_ASM_LOONG64_CPUCFG */\n"
"/* #define HAVE_ASM_LOONG64_DBAR */\n"
"/* #define HAVE_ASM_LOONG64_RDTIME */\n"
"/* #define HAVE_ASM_LOONG64_TLBRD */\n"
"/* #define HAVE_ASM_LOONG64_TLBSRCH */\n"
"/* #define HAVE_ASM_M68K_EORI_SR */\n"
"/* #define HAVE_ASM_MIPS_WAIT */\n"
"/* #define HAVE_ASM_PPC64_DARN */\n"
"/* #define HAVE_ASM_PPC64_DCBST */\n"
"/* #define HAVE_ASM_PPC64_DCBT */\n"
"/* #define HAVE_ASM_PPC64_DCBTST */\n"
"/* #define HAVE_ASM_PPC64_ICBI */\n"
"/* #define HAVE_ASM_PPC64_MSYNC */\n"
"/* #define HAVE_ASM_PPC64_TLBIE */\n"
"/* #define HAVE_ASM_PPC_DCBST */\n"
"/* #define HAVE_ASM_PPC_DCBT */\n"
"/* #define HAVE_ASM_PPC_DCBTST */\n"
"/* #define HAVE_ASM_PPC_ICBI */\n"
"/* #define HAVE_ASM_RISCV_CBO_CACHE_MANAGEMENT */\n"
"/* #define HAVE_ASM_RISCV_CBO_ZERO */\n"
"/* #define HAVE_ASM_RISCV_FENCE */\n"
"/* #define HAVE_ASM_RISCV_FENCE_I */\n"
"/* #define HAVE_ASM_RISCV_SFENCE_VMA */\n"
"/* #define HAVE_ASM_S390_PTLB */\n"
"/* #define HAVE_ASM_SH4_RTE */\n"
"/* #define HAVE_ASM_SH4_SLEEP */\n"
"/* #define HAVE_ASM_SPARC_MEMBAR */\n"
"/* #define HAVE_ASM_SPARC_RDPR */\n"
"/* #define HAVE_ASM_SPARC_TICK */\n"
"/* #define HAVE_ATTR_XATTR_H */\n"
"/* #define HAVE_BUILTIN_BITREVERSE */\n"
"/* #define HAVE_BUILTIN_CPU_IS_POWER10 */\n"
"/* #define HAVE_BUILTIN_CPU_IS_POWER11 */\n"
"/* #define HAVE_BUILTIN_CPU_IS_POWER9 */\n"
"/* #define HAVE_BUILTIN_NONTEMPORAL_LOAD */\n"
"/* #define HAVE_BUILTIN_NONTEMPORAL_STORE */\n"
"/* #define HAVE_BUILTIN_ROTATELEFT16 */\n"
"/* #define HAVE_BUILTIN_ROTATELEFT32 */\n"
"/* #define HAVE_BUILTIN_ROTATELEFT64 */\n"
"/* #define HAVE_BUILTIN_ROTATELEFT8 */\n"
"/* #define HAVE_BUILTIN_ROTATERIGHT16 */\n"
"/* #define HAVE_BUILTIN_ROTATERIGHT32 */\n"
"/* #define HAVE_BUILTIN_ROTATERIGHT64 */\n"
"/* #define HAVE_BUILTIN_ROTATERIGHT8 */\n"
"/* #define HAVE_CACHEFLUSH */\n"
"/* #define HAVE_DELETE_MODULE */\n"
"/* #define HAVE_EGL_EXT_H */\n"
"/* #define HAVE_EGL_H */\n"
"/* #define HAVE_FACCESSAT2 */\n"
"/* #define HAVE_FCHMODAT2 */\n"
"/* #define HAVE_FINIT_MODULE */\n"
"/* #define HAVE_Float128x */\n"
"/* #define HAVE_Float16x */\n"
"/* #define HAVE_Float80 */\n"
"/* #define HAVE_Float80x */\n"
"/* #define HAVE_GBM_H */\n"
"/* #define HAVE_GETEXECNAME */\n"
"/* #define HAVE_GETMNTINFO */\n"
"/* #define HAVE_GETXATTRAT */\n"
"/* #define HAVE_GLES2_H */\n"
"/* #define HAVE_HEAPSORT */\n"
"/* #define HAVE_INIT_MB_MGR_AVX */\n"
"/* #define HAVE_INTEL_IPSEC_MB_H */\n"
"/* #define HAVE_LIB_EGL */\n"
"/* #define HAVE_LIB_GBM */\n"
"/* #define HAVE_LIB_GLES2 */\n"
"/* #define HAVE_LIB_IPSEC_MB */\n"
"/* #define HAVE_LISTXATTRAT */\n"
"/* #define HAVE_LSM_GET_SELF_ATTR */\n"
"/* #define HAVE_LSM_LIST_MODULES */\n"
"/* #define HAVE_MACH_MACHINE_H */\n"
"/* #define HAVE_MACH_MACH_H */\n"
"/* #define HAVE_MACH_VM_STATISTICS_H */\n"
"/* #define HAVE_MEMBARRIER */\n"
"/* #define HAVE_MERGESORT */\n"
"/* #define HAVE_MM_STREAM_SI128 */\n"
"/* #define HAVE_MM_STREAM_SI32 */\n"
"/* #define HAVE_MM_STREAM_SI64 */\n"
"/* #define HAVE_MQUERY */\n"
"/* #define HAVE_MSEAL */\n"
"/* #define HAVE_OPEN_HOW */\n"
"/* #define HAVE_PPC_GET_TIMEBASE */\n"
"/* #define HAVE_PRAGMA_NO_HARD_DFP */\n"
"/* #define HAVE_PTHREAD_NP_H */\n"
"/* #define HAVE_QUOTACTL_FD */\n"
"/* #define HAVE_RADIXSORT */\n"
"/* #define HAVE_REMOVEXATTRAT */\n"
"/* #define HAVE_RFORK */\n"
"/* #define HAVE_SETXATTRAT */\n"
"/* #define HAVE_STIME */\n"
"/* #define HAVE_SYS_LOADAVG_H */\n"
"/* #define HAVE_SYS_MKDEV_H */\n"
"/* #define HAVE_SYS_PLATFORM_PPC_H */\n"
"/* #define HAVE_SYS_PROCCTL_H */\n"
"/* #define HAVE_SYS_SYSCTL_H */\n"
"/* #define HAVE_SYS_TREE_H */\n"
"/* #define HAVE_SYS_UCRED_H */\n"
"/* #define HAVE_SYS_VMMETER_H */\n"
"/* #define HAVE_TARGET_CLONES_AVXVNNI */\n"
"/* #define HAVE_TARGET_CLONES_POWER10 */\n"
"/* #define HAVE_TARGET_CLONES_POWER11 */\n"
"/* #define HAVE_TARGET_CLONES_POWER9 */\n"
"/* #define HAVE_TERMIO_H */\n"
"/* #define HAVE_USTAT */\n"
"/* #define HAVE_USTAT_H */\n"
"/* #define HAVE_UVM_UVM_EXTERN_H */\n"
"/* #define HAVE__ibm128 */\n"
"/* #define HAVE_fp16 */\n"
;
